@@ -8,12 +8,24 @@ fit.lung <- survreg(Surv(time, status) ~ sex + ph.ecog, data = lung)
 object <- fit.lung
 n.rep  <-  30
 newdata <- tibble::as_tibble(dplyr::select(lung, time, status, sex, ph.ecog))
+## ph.ecog == 3 only has one subject, also remove ph.ecog==NA
+newdata2 <-
+  tibble::as_tibble(dplyr::select(lung, time, status, sex, ph.ecog)) %>%
+  dplyr::filter(ph.ecog != 3)
 censor.dur <- c(200, 1100)
-
+## Test for trt with more than 2 categories
+newdata3 <-
+  tibble::as_tibble(dplyr::select(lung, time, status, sex, ph.ecog)) %>%
+  dplyr::filter(!is.na(ph.ecog)) %>%
+  dplyr::mutate(ph.ecog = factor(ph.ecog, levels = c(3, 1, 2, 0)))
+fit.lung.3 <- survreg(Surv(time, status) ~ sex, data = newdata3)
 
 sim <- suppressWarnings(surv_param_sim(object, newdata, n.rep, censor.dur))
 km.pi <- calc_km_pi(sim, group = "sex")
 
+sim.newdata2 <- suppressWarnings(surv_param_sim(object, newdata2, n.rep, censor.dur))
+sim.newdata3 <- suppressWarnings(surv_param_sim(fit.lung.3, newdata3, n.rep, censor.dur))
+
 test_that("setting last obs time for simulation", {
   expect_equal(km.pi$t.last, 1022)
 })
@@ -23,12 +35,19 @@ test_that("observed median time per group", {
 })
 
 test_that("Extract median quantile in wide format", {
-  median.pi.quantile <- extract_median_surv(km.pi, outtype ="wide")
+  median.pi.quantile <- extract_medsurv_pi(km.pi, outtype ="wide")
   expect_equal(dim(median.pi.quantile), c(2, 6))
   expect_equal(names(median.pi.quantile), c("pi_low", "pi_med", "pi_high", "obs", "sex", "n"))
-
+  expect_equal(median.pi.quantile$pi_med, c(281.2, 414.8), tolerance = 0.01)
 })
 
+test_that("`extract_median_surv()` still works", {
+  withr::local_options(list(lifecycle_verbosity = "quiet"))
+  median.pi.quantile <- extract_median_surv(km.pi)
+  expect_equal(median.pi.quantile$median[1:2], c(213.2723, 281.2060), tolerance = 0.01)
+})
+
+
 test_that("summary of prediction intervals for median survival time", {
   expect_equal(summary(km.pi)$median,
                c(213, 281, 331, 270, 298, 414, 535, 426),
@@ -65,16 +84,34 @@ test_that("grouping and trt", {
   plot.km.sex <- plot_km_pi(calc_km_pi(sim, trt = "sex"))
   expect_doppelganger("km plot with sex as trt", plot.km.sex)
 
-  plot.km.sex.ecog <- plot_km_pi(calc_km_pi(sim, group = c("sex", "ph.ecog")))
+  km.pi.sex.ecog <- suppressWarnings(calc_km_pi(sim, group = c("sex", "ph.ecog")))
+  plot.km.sex.ecog <- plot_km_pi(km.pi.sex.ecog)
   expect_doppelganger("km plot with sex and ph.ecog as group", plot.km.sex.ecog)
 })
 
 
-test_that("long simulation time", {
-  km.pi.longsim <- calc_km_pi(sim, group = "sex", simtimelast = 2000)
+test_that("median survival delta", {
+  km.pi.ph.ecog <- suppressWarnings(calc_km_pi(sim.newdata3, trt = "ph.ecog", group = "sex", trt.assign = "reverse"))
+
+  medsurv.delta <- extract_medsurv_delta(km.pi.ph.ecog)
+
+  expect_equal(dim(medsurv.delta), c(180, 4))
+  expect_equal(medsurv.delta[[2, "median_delta"]], 70,
+               tolerance = 1)
+})
+
+test_that("median survival delta prediction interval", {
+  km.pi.newdata2 <- calc_km_pi(sim.newdata2, trt = "sex", group = "ph.ecog")
+
+  extract_medsurv_delta_pi(km.pi.newdata2, outtype = "wide") %>%
+    dplyr::select(pi_low, pi_high) %>%
+    as.data.frame() %>%
+    dplyr::mutate(pi_low  = unname(pi_low),
+                  pi_high = unname(pi_high)) %>%
+    expect_equal(data.frame(pi_low  = c(-32, 32, -54),
+                            pi_high = c(647, 325, 235)),
+                 tolerance = 0.01)
 
-  expect_doppelganger("long sim time, not truncating with censor", plot_km_pi(km.pi.longsim, trunc.sim.censor = FALSE))
-  expect_doppelganger("long sim time, truncating with censor", plot_km_pi(km.pi.longsim))
 })
 
 
@@ -84,7 +121,7 @@ test_that("no group or trt", {
 
   summary(km.pi.no.group.trt) %>%
     dplyr::pull(median) %>%
-    expect_equal(c(279, 320, 363, 310), tolerance = 1)
+    expect_equal(c(279, 320, 363, 310), tolerance = 0.01)
 
 })
 
@@ -94,4 +131,10 @@ test_that("not calculating observed KM", {
 
 })
 
+test_that("warning with immature median time simulations", {
+  sim <- suppressWarnings(surv_param_sim(object, newdata, n.rep, censor.dur = c(50, 100)))
+  expect_warning(calc_km_pi(sim, group = "sex"))
+
+})
+
 
